# coding: utf-8

"""
    Catalog Next API.

    This documentation describes the Catalog Next API for all versions and other miscellaneous endpoints.  # noqa: E501

    OpenAPI spec version: 1.16.7+dcs
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import dcs_catalog_client
from dcs_catalog_client.models.catalog_v3 import CatalogV3  # noqa: E501
from dcs_catalog_client.rest import ApiException


class TestCatalogV3(unittest.TestCase):
    """CatalogV3 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCatalogV3(self):
        """Test CatalogV3"""
        # FIXME: construct object with mandatory attributes with example values
        # model = dcs_catalog_client.models.catalog_v3.CatalogV3()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
